Tinkerer
========

.. image:: https://travis-ci.org/vladris/tinkerer.png
   :target: https://travis-ci.org/vladris/tinkerer/
   
.. image:: https://coveralls.io/repos/vladris/tinkerer/badge.png 
   :target: https://coveralls.io/r/vladris/tinkerer

What is Tinkerer?
-----------------

Tinkerer is a blogging engine/static website generator powered by Sphinx.

It allows blogging in reStructuredText format, comes with out-of-the-box 
support for post publishing dates, authors, categories, tags, post archive,
RSS feed generation, comments powered by Disqus and more.

Tinkerer is also highly customizable through Sphinx extensions.

Why Tinkerer?
-------------

* Because *"hacker"* is way overused nowadays.
* Because static websites are cool.
* Because you already write documentation in RST format and you love it.
* Because you have Pygments for sharing highlighted code.
* Because you can use your favorite Sphinx extensions right away.

How to Tinker?
--------------

Get Tinkerer::

    pip install tinkerer

Skim through the `Documentation <http://tinkerer.me/pages/documentation.html>`_.

